@@ -2,13 +2,13 @@
 function(data) {
    lmom <- lmom.ub(data)
    para <- parglo(lmom)
-   print("GENERALIZED LOGISTIC DISTRIBUTION PARAMETERS")
-   print(para)
+   cat("GENERALIZED LOGISTIC DISTRIBUTION PARAMETERS\n")
+   str(para)
    lmompara <- lmomglo(para)
    Q50 <- quaglo(0.5,para)
-   print(c('MEDIAN ',Q50))
+   cat(c("Computed median=",Q50,"\n"),sep="")
    P50 <- cdfglo(Q50,para)
-   print(c('NONEXCEEDANCE OF COMPUTED MEDIAN ',P50))
+   cat(c("Nonexceedance of computed median=",P50,"\n"),sep="")
    lmom.diff(lmompara,lmom)
 }
 
